@@ -17,26 +17,32 @@
  * You should have received a copy of the GNU General Public License
  * with Fisoco.  If not, see <http://www.gnu.org/licenses/>.
  *//////////////////////////////////////
- /***********
-  * global.h *
-  * ~~~~~~~~ *
-  ************/
- 
- #ifndef FISOCO_GLOBAL_H
- #define FISOCO_GLOBAL_H
- 
- #if HAVE_CONFIG_H
- #  include <config.h>
- #endif /* HAVE_CONFIG_H */
- #if HAVE_UNISTD_H
- #  include <unistd.h>
- #endif /* HAVE_UNISTD_H */
- #include <iostream>
- 
- void activate_debug (bool state);
- void debug (std::string message);
- void error (std::string message);
- extern bool debug_ok;
- 
- #endif // FISOCO_GLOBAL_H
- 
+/***********
+ * global.h *
+ * ~~~~~~~~ *
+ ************/
+
+#ifndef FISOCO_GLOBAL_H
+#define FISOCO_GLOBAL_H
+
+#if HAVE_CONFIG_H
+#  include <config.h>
+#endif /* HAVE_CONFIG_H */
+#if HAVE_UNISTD_H
+#  include <unistd.h>
+#endif /* HAVE_UNISTD_H */
+#include <iostream>
+// i18n
+#include "gettext.h"
+
+void activate_debug (bool state);
+void debug (std::string message);
+void error (std::string message);
+void goodnews (std::string message);
+void help ();
+void version ();
+
+extern bool debug_ok;
+
+#endif // FISOCO_GLOBAL_H
+
