@@ -17,37 +17,37 @@
  * You should have received a copy of the GNU General Public License
  * with Fisoco.  If not, see <http://www.gnu.org/licenses/>.
  *//////////////////////////////////////
- /**********
+/***********
  * list.cc *
  * ~~~~~~~ *
  ***********/
- 
- #include "../include/global.h"
- #include "../include/list.h"
- 
- // List functions
- 
- List::List ()
- {
- }
- 
- void
- List::add_file (std::string dir, std::string file)
- {
-     std::string dbg_message = gettext ("Adding ") + file + gettext (" in list");
-     debug (dbg_message);
-     File *new_one;
-     new_one = new File ();
-     new_one->set_filename (file);
-     new_one->set_filepath (dir);
-     Llist.push_back (new_one);
- }
- 
- void
- List::del_file (int id)
- {
- }
- 
+
+#include "../include/global.h"
+#include "../include/list.h"
+
+// List functions
+
+List::List ()
+{
+}
+
+void
+List::add_file (std::string dir, std::string file)
+{
+  std::string dbg_message = gettext ("Adding ") + file + gettext (" in list");
+  debug (dbg_message);
+  File *new_one;
+  new_one = new File ();
+  new_one->set_filename (file);
+  new_one->set_filepath (dir);
+  Llist.push_back (new_one);
+}
+
+void
+List::del_file (int id)
+{
+}
+
 std::list<std::string>
 List::get_complete_names ()
 {
@@ -64,17 +64,18 @@ List::get_infos (int id)
   if (id <= (int)Llist.size ())
     {
       File *file = Llist[(id-1)];
-      std::string dbg_message = gettext ("Asking infos about the ") + std::to_string (id) + gettext ("# file...");
+      std::string dbg_message = gettext ("Asking infos about the ")
+	+ std::to_string (id) + gettext ("# file...");
       debug (dbg_message);
       infos.push_back (file->get_filename ());
       infos.push_back (file->get_filepath ());
+      //      free (file);
     }
   else
     {
       std::string err_message = gettext ("Can't ask infos about the ") + std::to_string (id) + gettext ("# file !!");
       error (err_message);
     }
-  // Et caetera...
   return infos;
 }
 
@@ -89,34 +90,34 @@ List::select (int id)
 {
 }
 
- // File functions 
- 
- List::File::File ()
- {
- }
- 
- void
- List::File::set_filename (std::string name)
- {
-     filename = name;
- }
- 
- std::string
- List::File::get_filename ()
- {
-     return filename;
- }
- 
- void
- List::File::set_filepath (std::string path)
- {
-     filepath = path;
- }
- 
- std::string
- List::File::get_filepath ()
- {
-     return filepath;
- }
- 
- 
+// File functions 
+
+List::File::File ()
+{
+}
+
+void
+List::File::set_filename (std::string name)
+{
+  filename = name;
+}
+
+std::string
+List::File::get_filename ()
+{
+  return filename;
+}
+
+void
+List::File::set_filepath (std::string path)
+{
+  filepath = path;
+}
+
+std::string
+List::File::get_filepath ()
+{
+  return filepath;
+}
+
+
